# Installation

The installation can be done using either ssh or https:

## SSH
`pip install -e "git+ssh://git@bitbucket.org/somalabs/soma-tools.git/#egg=soma&subdirectory=soma_pkg/"`

## HTTPS
`pip install -e "git+https://bitbucket.org/somalabs/soma-tools.git/#egg=soma&subdirectory=soma_pkg/"`